@@ -17,7 +17,7 @@ macro_rules! test_assertion {
 #[macro_export]
 macro_rules! assert_does_not_throw {
     ($body: block $(,)?) => {
-        assert_eq!(test_assertion!($body), Ok(()))
+        assert_eq!($crate::test_assertion!($body), Ok(()))
     };
 }
 
@@ -27,7 +27,7 @@ macro_rules! assert_does_not_throw {
 #[macro_export]
 macro_rules! assert_throws {
     ($body: block, $right: expr $(,)?) => {
-        assert_eq!(test_assertion!($body), Err($right.into()))
+        assert_eq!($crate::test_assertion!($body), Err($right.into()))
     };
 }
 
@@ -174,23 +174,24 @@ macro_rules! throw_err {
 )]
 macro_rules! assert_ata {
     ($ata: expr, $owner: expr, $mint: expr $(,)?) => {
-        assert_ata!($ata, $owner, $mint, "ata mismatch")
+        $crate::assert_ata!($ata, $owner, $mint, "ata mismatch")
     };
     ($ata: expr, $owner: expr, $mint: expr, $msg: expr $(,)?) => {{
-        let __owner = anchor_lang::Key::key(&$owner);
-        let __mint = anchor_lang::Key::key(&$mint);
-        let __ata = anchor_lang::Key::key(&$ata);
-        let __real_ata = $crate::ata::get_associated_token_address(&__owner, &__mint);
-        if __real_ata != __ata {
+        let __ata = $crate::AsKeyRef::as_key_ref(&$ata);
+        let __real_ata = $crate::ata::get_associated_token_address(
+            $crate::AsKeyRef::as_key_ref(&$owner),
+            $crate::AsKeyRef::as_key_ref(&$mint),
+        );
+        if &__real_ata != __ata {
             msg!(
                 "ATA mismatch: {}: {} (left) != {} (right)",
                 $msg,
                 __ata,
                 __real_ata
             );
-            msg!("Owner: {}", __owner);
-            msg!("Mint: {}", __mint);
-            return Err($crate::VipersError::ATAMismatch.into());
+            msg!("Owner: {}", $crate::AsKeyRef::as_key_ref(&$owner));
+            msg!("Mint: {}", $crate::AsKeyRef::as_key_ref(&$mint));
+            $crate::throw_err!($crate::VipersError::ATAMismatch);
         }
     }};
 }
@@ -220,7 +221,7 @@ macro_rules! assert_is_ata {
             );
             msg!("Owner: {}", __owner);
             msg!("Mint: {}", __mint);
-            return Err($crate::VipersError::InvalidATA.into());
+            $crate::throw_err!($crate::VipersError::InvalidATA);
         }
     }};
 }
@@ -247,8 +248,8 @@ macro_rules! assert_owner {
     };
     ($program_account: expr, $owner: expr, $msg: expr $(,)?) => {{
         let __program_account =
-            *anchor_lang::ToAccountInfo::to_account_info(&$program_account).owner;
-        let __owner = $owner.key();
+            anchor_lang::ToAccountInfo::to_account_info(&$program_account).owner;
+        let __owner = $crate::AsKeyRef::as_key_ref(&$owner);
         if __program_account != __owner {
             msg!(
                 "Owner mismatch: {}: expected {}, got {}",
@@ -308,8 +309,8 @@ macro_rules! assert_keys_eq {
         $crate::assert_keys_eq!($account_a, $account_b, $err, $crate::format_err!($err));
     };
     ($account_a: expr, $account_b: expr, $err: expr, $msg: expr $(,)?) => {{
-        let __account_a = $account_a.key();
-        let __account_b = $account_b.key();
+        let __account_a = $crate::AsKeyRef::as_key_ref(&$account_a);
+        let __account_b = $crate::AsKeyRef::as_key_ref(&$account_b);
         if __account_a != __account_b {
             msg!($msg);
             msg!(stringify!($account_a != $account_b));
@@ -436,8 +437,8 @@ macro_rules! assert_keys_neq {
         $crate::assert_keys_neq!($account_a, $account_b, $err, $crate::format_err!($err));
     };
     ($account_a: expr, $account_b: expr, $err: expr, $msg: expr $(,)?) => {{
-        let __account_a = $account_a.key();
-        let __account_b = $account_b.key();
+        let __account_a = $crate::AsKeyRef::as_key_ref(&$account_a);
+        let __account_b = $crate::AsKeyRef::as_key_ref(&$account_b);
         if __account_a == __account_b {
             msg!($msg);
             msg!(stringify!($account_a == $account_b));
@@ -655,140 +656,3 @@ macro_rules! assert_keys {
         $crate::assert_keys_eq!($account_a, $account_b, $msg)
     };
 }
-
-#[cfg(test)]
-mod tests {
-    use crate::prelude::*;
-    use anchor_lang::prelude::*;
-    use anchor_spl::token;
-    use spl_associated_token_account::get_associated_token_address;
-
-    #[error]
-    pub enum ErrorCode {
-        MyError,
-    }
-
-    #[account]
-    #[derive(Default)]
-    struct TestData {
-        pub byte: u8,
-    }
-
-    #[test]
-    #[allow(deprecated)]
-    fn test_compiles_deprecated() -> ProgramResult {
-        assert_keys!(token::ID, token::ID, "token program");
-
-        Ok(())
-    }
-
-    #[test]
-    #[allow(deprecated)]
-    fn test_compiles() -> ProgramResult {
-        assert_ata!(
-            get_associated_token_address(&token::ID, &token::ID),
-            token::ID,
-            token::ID,
-            "ATA"
-        );
-
-        let weird_math: Option<i32> = (1_i32).checked_add(2);
-        let _result = unwrap_int!(weird_math);
-        unwrap_opt!(weird_math, "aaa");
-
-        Ok(())
-    }
-
-    #[test]
-    #[allow(deprecated)]
-    fn test_assert_owner() -> ProgramResult {
-        let mut lamports: u64 = 8 + (TestData::default().try_to_vec().unwrap().len() as u64);
-
-        let mut buffer: [u8; 16] = [0; 16];
-        let mut buf: &mut [u8] = &mut buffer;
-        TestData::default().try_serialize(&mut buf)?;
-
-        let info: Account<TestData> = Account::try_from(&AccountInfo::new(
-            &crate::ID,
-            false,
-            false,
-            &mut lamports,
-            &mut buffer,
-            &crate::ID,
-            false,
-            0,
-        ))?;
-        assert_owner!(info, crate::ID);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_unwrap_checked() -> ProgramResult {
-        assert_throws!(
-            {
-                unwrap_checked!({
-                    let one: u64 = 1;
-                    let four = one.checked_add(u64::MAX)?;
-                    four.checked_add(3)
-                });
-            },
-            VipersError::IntegerOverflow
-        );
-        Ok(())
-    }
-
-    #[test]
-    fn test_unwrap_opt_block() {
-        assert_throws!(
-            {
-                unwrap_opt_block!(
-                    {
-                        let one: u64 = 1;
-                        one.checked_add(u64::MAX)
-                    },
-                    ErrorCode::MyError
-                );
-            },
-            ErrorCode::MyError
-        );
-    }
-
-    #[test]
-    #[allow(clippy::eq_op)]
-    fn test_invariant() {
-        assert_does_not_throw!({
-            invariant!(1 == 1, ErrorCode::MyError);
-        });
-        assert_throws!(
-            {
-                invariant!(1 == 2);
-            },
-            VipersError::InvariantFailed
-        );
-        assert_throws!(
-            {
-                invariant!(1 == 2, "this is stupid");
-            },
-            VipersError::InvariantFailed
-        );
-        assert_throws!(
-            {
-                invariant!(1 == 2, ErrorCode::MyError);
-            },
-            ErrorCode::MyError
-        );
-        assert_throws!(
-            {
-                invariant!(1 == 2, ErrorCode::MyError);
-            },
-            ErrorCode::MyError
-        );
-        assert_throws!(
-            {
-                invariant!(1 == 2, ErrorCode::MyError, "this is wack");
-            },
-            ErrorCode::MyError
-        );
-    }
-}
